aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/compiler/xla/service/algebraic_simplifier.h
diff options
context:
space:
mode:
Diffstat (limited to 'tensorflow/compiler/xla/service/algebraic_simplifier.h')
-rw-r--r--tensorflow/compiler/xla/service/algebraic_simplifier.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/tensorflow/compiler/xla/service/algebraic_simplifier.h b/tensorflow/compiler/xla/service/algebraic_simplifier.h
index f8919f0caa..4295a3227a 100644
--- a/tensorflow/compiler/xla/service/algebraic_simplifier.h
+++ b/tensorflow/compiler/xla/service/algebraic_simplifier.h
@@ -26,12 +26,13 @@ namespace xla {
// A pass which performs AlgebraicSimplications.
class AlgebraicSimplifier : public HloPassInterface {
public:
- // Given two shapes, determines if it is valid to bitcast between them after
- // considering platform dependent effects on layout like alignment
- // restrictions.
- // Precondition: the two shapes have layouts, the same number of
- // elements and ShapeUtil::ReshapeIsBitcast returns true.
- using ValidBitcastCallback = std::function<bool(const Shape&, const Shape&)>;
+ // Given shapes 'from_shape' and 'to_shape', determines if it is valid to
+ // bitcast from 'from_shape' to 'to_shape' after considering platform
+ // dependent effects on layout like alignment restrictions. Precondition: the
+ // two shapes have layouts, the same number of elements and
+ // ShapeUtil::ReshapeIsBitcast returns true.
+ using ValidBitcastCallback =
+ std::function<bool(const Shape& from_shape, const Shape& to_shape)>;
// If is_layout_sensitive is true, then the simplifier preserves layout during
// transformation. Otherwise, layout is ignored. If valid_bitcast_callback